==> dcoupon_sdk_flutter_package-2.0.0.tar.gz: lib/src/themes/dark_theme.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:flutter/material.dart';

ThemeData dCouponDarkBlack() {
  final baseTheme = ThemeData.dark().copyWith(
    textTheme: ThemeData.dark().textTheme.apply(fontFamily: 'Poppins'),
    primaryTextTheme:
        ThemeData.dark().primaryTextTheme.apply(fontFamily: 'Poppins'),
    accentTextTheme:
        ThemeData.dark().accentTextTheme.apply(fontFamily: 'Poppins'),
  );

  return baseTheme.copyWith(
    accentColor: DCouponColors.dCouponPrimaryOrange,
    primaryColor: DCouponColors.dCouponPrimaryOrange,
    primaryColorDark: DCouponColors.dCouponPrimaryBlack,
    scaffoldBackgroundColor: DCouponColors.dCouponPrimaryBlack,
    colorScheme: baseTheme.colorScheme.copyWith(
      background: Colors.grey[900],
    ),
    bottomAppBarTheme: baseTheme.bottomAppBarTheme.copyWith(
      color: DCouponColors.dCouponPrimaryBlack,
    ),
    snackBarTheme: baseTheme.snackBarTheme.copyWith(
      backgroundColor: DCouponColors.dCouponPrimaryOrange,
      contentTextStyle: baseTheme.textTheme.bodyText2.copyWith(
        color: DCouponColors.dCouponWhite,
      ),
    ),
    appBarTheme: baseTheme.appBarTheme.copyWith(
      color: DCouponColors.dCouponPrimaryBlack,
      brightness: Brightness.dark,
    ),
    buttonTheme: baseTheme.buttonTheme.copyWith(
      buttonColor: DCouponColors.dCouponPrimaryOrange,
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    iconTheme: baseTheme.iconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    cursorColor: DCouponColors.dCouponPrimaryOrange,
    textSelectionHandleColor: DCouponColors.dCouponPrimaryOrange,
    bottomAppBarColor: DCouponColors.dCouponPrimaryBlack,
    floatingActionButtonTheme: FloatingActionButtonThemeData(
        backgroundColor: DCouponColors.dCouponPrimaryOrange,
        foregroundColor: DCouponColors.dCouponWhite),
    cardColor: DCouponColors.dCouponPrimaryBlack,
    toggleableActiveColor: DCouponColors.dCouponPrimaryOrange,
  );
}

==> dcoupon_sdk_flutter_package-4.0.1.tar.gz: lib/src/themes/dark_theme.dart <==
import 'package:dcoupon_sdk_flutter_package/src/presentation/colors.dart';
import 'package:flutter/material.dart';

ThemeData dCouponDarkBlack() {
  final baseTheme = ThemeData.dark().copyWith(
    textTheme: ThemeData.dark().textTheme.apply(fontFamily: 'Poppins'),
    primaryTextTheme:
        ThemeData.dark().primaryTextTheme.apply(fontFamily: 'Poppins'),
    accentTextTheme:
        ThemeData.dark().accentTextTheme.apply(fontFamily: 'Poppins'),
  );

  return baseTheme.copyWith(
    accentColor: DCouponColors.dCouponPrimaryOrange,
    primaryColor: DCouponColors.dCouponPrimaryOrange,
    primaryColorDark: DCouponColors.dCouponPrimaryBlack,
    scaffoldBackgroundColor: DCouponColors.dCouponPrimaryBlack,
    colorScheme: baseTheme.colorScheme.copyWith(
      background: Colors.grey[900],
      primary: DCouponColors.dCouponPrimaryOrange,
    ),
    bottomAppBarTheme: baseTheme.bottomAppBarTheme.copyWith(
      color: DCouponColors.dCouponPrimaryBlack,
    ),
    snackBarTheme: baseTheme.snackBarTheme.copyWith(
      backgroundColor: DCouponColors.dCouponPrimaryOrange,
      contentTextStyle: baseTheme.textTheme.bodyText2!.copyWith(
        color: DCouponColors.dCouponWhite,
      ),
    ),
    appBarTheme: baseTheme.appBarTheme.copyWith(
      color: DCouponColors.dCouponPrimaryBlack,
      brightness: Brightness.dark,
    ),
    buttonTheme: baseTheme.buttonTheme.copyWith(
      buttonColor: DCouponColors.dCouponPrimaryOrange,
    ),
    elevatedButtonTheme: ElevatedButtonThemeData(
      style: ElevatedButton.styleFrom(
        primary: DCouponColors.dCouponPrimaryOrange,
      ),
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    iconTheme: baseTheme.iconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: DCouponColors.dCouponPrimaryOrange,
    ),
    textSelectionTheme: baseTheme.textSelectionTheme.copyWith(
      selectionHandleColor: DCouponColors.dCouponPrimaryOrange,
      cursorColor: DCouponColors.dCouponPrimaryOrange,
    ),
    bottomAppBarColor: DCouponColors.dCouponPrimaryBlack,
    floatingActionButtonTheme: FloatingActionButtonThemeData(
        backgroundColor: DCouponColors.dCouponPrimaryOrange,
        foregroundColor: DCouponColors.dCouponWhite),
    cardColor: DCouponColors.dCouponPrimaryBlack,
    toggleableActiveColor: DCouponColors.dCouponPrimaryOrange,
  );
}
